@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: desc.c,v 1.9 2001/03/08 13:59:00 hughesj Exp $
+ *	$Id: desc.c,v 1.12 2003/01/14 07:53:31 roland Exp $
  */
 
 #include "defs.h"
@@ -212,7 +212,7 @@ int getlk;
 static void
 printflock64(tcp, addr, getlk)
 struct tcb *tcp;
-int addr;
+long addr;
 int getlk;
 {
 	struct flock64 fl;
@@ -225,7 +225,7 @@ int getlk;
 	printxval(lockfcmds, fl.l_type, "F_???");
 	tprintf(", whence=");
 	printxval(whence, fl.l_whence, "SEEK_???");
-	tprintf(", start=%lld, len=%lld", fl.l_start, fl.l_len);
+	tprintf(", start=%lld, len=%lld", (long long) fl.l_start, (long long) fl.l_len);
 	if (getlk)
 		tprintf(", pid=%lu}", (unsigned long) fl.l_pid);
 	else
@@ -291,7 +291,7 @@ struct tcb *tcp;
 #ifdef F_FREESP64
 		case F_FREESP64:
 #endif
-		/* Linux glibc defines SETLK64 as SETLK, 
+		/* Linux glibc defines SETLK64 as SETLK,
 		   even though the kernel has different values - as does Solaris. */
 #if defined(F_SETLK64) && F_SETLK64+0!=F_SETLK
 		case F_SETLK64:
@@ -540,6 +540,7 @@ struct tcb *tcp;
 }
 
 #ifdef ALPHA
+int
 sys_osf_select(tcp)
 struct tcb *tcp;
 {
